package com.jz.dmp.modules.controller.DataIntegration;

import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.page.BasePageBean;
import com.jz.common.page.PageInfoResponse;
import com.jz.dmp.modules.controller.DataIntegration.bean.DataSourceListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.DataSourceListReq;
import com.jz.dmp.modules.controller.DataIntegration.bean.DmpSyncingDatasourceReq;
import com.jz.dmp.modules.controller.DataIntegration.bean.DvRuleTDto;
import com.jz.dmp.modules.model.DmpSyncingDatasource;
import com.jz.dmp.modules.service.DmpSyncingDatasourceService;
import com.jz.dmp.modules.service.OfflineSynchService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * @Description:数据源
 * @ClassName: DataSourceController
 * @Author Bellamy
 * @Date 2020/12/20
 */
@RestController
@RequestMapping("/dataSourceMange")
@Api(tags = "数据集成--数据源")
public class DataSourceController {

    @Autowired
    private DmpSyncingDatasourceService dmpSyncingDatasourceService;

    /**
     * 数据源列表分页查询
     *
     * @return
     */
    @ApiOperation(value = "数据源列表分页查询", notes = "数据源列表分页查询")
    @PostMapping(value = "/dataSourceListPage")
    public PageInfoResponse<DataSourceListDto> getDataSourceListPage(@RequestBody DataSourceListReq req, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<DataSourceListDto> pageInfo = new PageInfoResponse<DataSourceListDto>();
        if (StringUtils.isEmpty(req.getProjectId())) {
            pageInfo.setMessage("项目id不能为空！");
            pageInfo.setCode(ResultCode.PARAMS_ERROR);
            return pageInfo;
        }
        try {
            pageInfo = dmpSyncingDatasourceService.queryDataSourceListPage(req, httpRequest);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 批量删除数据源
     *
     * @return
     */
    @ApiImplicitParam(name = "datasourceId", value = "数据源id")
    @ApiOperation(value = "批量删除数据源", notes = "批量删除数据源")
    @GetMapping(value = "/delDataSource")
    public JsonResult delDataSource(@RequestParam String datasourceId, HttpServletRequest httpRequest) throws Exception {
        if(StringUtils.isEmpty(datasourceId)){
            return new JsonResult(ResultCode.PARAMS_ERROR);
        }
        JsonResult result = dmpSyncingDatasourceService.delDataSourceById(datasourceId);
        return result;
    }

    /**
     * 获取数据源类型-下拉框
     *
     * @return
     */
    @ApiOperation(value = "获取数据源类型", notes = "获取数据源类型-下拉框")
    @GetMapping(value = "/queryDatasourceType")
    public JsonResult getDatasourceType(HttpServletRequest httpRequest) throws Exception {
        JsonResult result = dmpSyncingDatasourceService.queryDatasourceType();
        return result;
    }

    /**
     * 新增获取数据源类型
     *
     * @return
     */
    @ApiOperation(value = "新增--获取数据源类型", notes = "获取数据源类型")
    @GetMapping(value = "/queryGroupDatasourceType")
    public JsonResult getGroupDatasourceType(HttpServletRequest httpRequest) throws Exception {
        JsonResult result = dmpSyncingDatasourceService.queryGroupDatasourceType();
        return result;
    }

    /**
     * 保存数据源
     *
     * @return
     */
    @ApiOperation(value = "保存数据源", notes = "保存数据源")
    @PostMapping(value = "/addDatasourceInfo")
    public JsonResult addDatasourceInfo(@RequestBody @Validated DmpSyncingDatasourceReq saveBody, HttpServletRequest httpRequest) throws Exception {
        JsonResult result = dmpSyncingDatasourceService.addDatasourceInfo(saveBody);
        return result;
    }
}
